@@ -11,7 +11,7 @@ subroutine akj(x,z,p,iker,dens,psi,score,nx,nz,h,alpha,kappa,xlam)
 # score--(log(f(z)))'', the J fn at z
 # nx--number of pts in x
 # nz--number of pts in z
-# iker--kernel 
+# iker--kernel
 #          0=gaussian
 #	   1=cauchy
 # h--initial window size (overall)--choose zero for default
@@ -31,46 +31,46 @@ parameter( fifth = 0.2d0)
 parameter( pi = 3.141593d0)
 xn=nx
 
-#call srtad(x,1,nx) #port sort routine now done in S interface.
-if(iker==0)con1=one/sqrt(2.0*pi)
-else if(iker==1)con1=one/pi
+# call srtad(x,1,nx) # port sort routine now done in S interface.
+if(iker==0) con1=one/sqrt(2.0*pi)
+else if(iker==1) con1=one/pi
 
-#if no h is provided, calculate a default
-if(h<=0.){
+# if no h is provided, calculate a default
+if(h<=0.) {
 	sum=0.
 	sqsum=0.
 	do i=1,nx
-		{sqsum=sqsum+x(i)*x(i)*p(i)
+		{ sqsum=sqsum+x(i)*x(i)*p(i)
 		sum=sum+x(i)*p(i)
 		}
 	xsd=dsqrt(sqsum-sum*sum)
 	sum=zero
-	for(i=1;i<nx;i=i+1){
+	for(i=1;i<nx;i=i+1) {
 		sum=sum+p(i)
-		if(sum<.25)next
-		else{qrange=x(i);break}
+		if(sum<.25) next
+		else { qrange=x(i);break }
 		}
 	sum=one
-	for(i=nx;i>0;i=i-1){
+	for(i=nx;i>0;i=i-1) {
 		sum=sum-p(i)
-		if(sum>.75)next
-		else{qrange=x(i)-qrange;break}
+		if(sum>.75) next
+		else { qrange=x(i)-qrange;break }
 		}
 	a=min(xsd,qrange/1.34)
-	h=kappa*a/(xn**fifth) #see Silverman p 48
+	h=kappa*a/(xn**fifth) # see Silverman p 48
 	}
 hinv=one/h
-#Stage one:  compute pilot estimate of density
-	do j=1,nx{
+# Stage one:  compute pilot estimate of density
+	do j=1,nx {
 		xker=0.
-		if(iker==0){
+		if(iker==0) {
 			do i=1,nx {
 				xponen=(x(j)-x(i))*hinv
 				xponen=half*xponen**2
 				xker=xker+p(i)*exp(-xponen)*hinv
 				}
 			}
-		else if(iker==1){
+		else if(iker==1) {
 			do i=1,nx {
 				xponen=(x(j)-x(i))*hinv
 				xker=xker+p(i)*hinv/(1+xponen**2)
@@ -78,44 +78,44 @@ hinv=one/h
 			}
 		xlam(j)=con1*xker
 		}
-#Stage two:  Automatic window widths (Silverman p101)
+# Stage two:  Automatic window widths (Silverman p101)
 	glog=zero
 	do i=1,nx
-		{glog=glog+p(i)*log(xlam(i))}
+		{ glog=glog+p(i)*log(xlam(i))}
 	g=exp(glog)
 	ginv=one/g
-	do i=1,nx{
-		xlam(i)=hinv/((xlam(i)*ginv)**(-alpha))
-		}
-#notice xlam no longer its own self at this pt! xlam is 1/(h*lambda(i))
-#substitution of * for / thus achieved speeds things up
+	do i=1,nx {
+            xlam(i)=hinv/((xlam(i)*ginv)**(-alpha))
+        }
+# notice xlam no longer its own self at this pt! xlam is 1/(h*lambda(i))
+# substitution of * for / thus achieved speeds things up
 
-#Stage two:  new density-score estimates
-	do j=1,nz{
+# Stage two:  new density-score estimates
+	do j=1,nz {
 		xker=zero
 		dxker=zero
 		ddxker=zero
-		if(iker==0){
-			do i=1,nx {  #gaussian kernel
-				xponen=(z(j)-x(i))*xlam(i)
-				fact=exp(-half*xponen*xponen)*xlam(i)
-				xker=xker+p(i)*fact
-				dxker=dxker-p(i)*fact*xponen*xlam(i)
-				ddxker=ddxker-
-					p(i)*fact*(one - xponen**2)*xlam(i)**2
-				}
-			}
-		if(iker==1){	# cauchy kernel 
-			do i=1,nx {
-				xponen=(z(j)-x(i))*xlam(i)
-				fact=xlam(i)/(one+xponen**2)
-				xker=xker+p(i)*fact
-				dxker=dxker-p(i)*two*xponen*fact**2
-				ddxker=ddxker-
-					p(i)*two*(fact**2)*(xlam(i)-
-					four*(xponen**2)*fact)
-				}
-			}
+		if(iker==0) {  # gaussian kernel
+                    do i=1,nx {
+                        xponen=(z(j)-x(i))*xlam(i)
+                        fact=exp(-half*xponen*xponen)*xlam(i)
+                        xker=xker+p(i)*fact
+                        dxker=dxker-p(i)*fact*xponen*xlam(i)
+                        ddxker=ddxker-
+                            p(i)*fact*(one - xponen**2)*xlam(i)**2
+                    }
+                }
+		else if(iker==1) {  # cauchy kernel
+                    do i=1,nx {
+                        xponen=(z(j)-x(i))*xlam(i)
+                        fact=xlam(i)/(one+xponen**2)
+                        xker=xker+p(i)*fact
+                        dxker=dxker-p(i)*two*xponen*fact**2
+                        ddxker=ddxker-
+                            p(i)*two*(fact**2)*(xlam(i)-
+                                                four*(xponen**2)*fact)
+                    }
+                }
 		dens(j)=con1*xker
 		psi(j)=-(dxker/xker)
 		score(j)=(dxker/xker)**2-ddxker/xker
